@@ -28,6 +28,7 @@ from __future__ import print_function
 import sys
 import collections
 import os
+import argparse
 
 from luigi import build, worker
 
@@ -310,7 +311,6 @@ def resolve_bundle(pipe, data_context):
         if verbose: print("resolve_bundle: found ExternalDepTask re-using bundle with UUID[{}].\n".format(pipe.uuid))
         b = api.get(data_context.get_local_name(), None, uuid=pipe.uuid)  # TODO:cache b in ext dep object, no 2x lookup
         if b is None:
-            _logger.warn(f"Unable to resolve bundle[{pipe.uuid}] in context[{data_context.get_local_name()}]")
             reuse_bundle(pipe, b, pipe.uuid, data_context)  # Ensure that the PCE results in a file that cannot be found
         else:
             reuse_bundle(pipe, b, b.uuid, data_context)
@@ -538,3 +538,32 @@ def cli_apply(args):
 
     # If we didn't successfully run any task, sys.exit with non-zero code
     common.apply_handle_result(result)
+
+
+def add_arg_parser(subparsers):
+    """Initialize a command line set of subparsers with file system commands.
+
+    Args:
+        subparsers: A collection of subparsers as defined by `argsparse`.
+    """
+
+    apply_p = subparsers.add_parser('apply', description="Apply a transform to an input bundle to produce an output bundle.")
+    apply_p.add_argument('-cs', '--central-scheduler', action='store_true', default=False, help="Use a central Luigi scheduler (defaults to local scheduler)")
+    apply_p.add_argument('-w', '--workers', type=int, default=1, help="Number of Luigi workers on this node")
+    apply_p.add_argument('-it', '--input-tag', nargs=1, type=str, action='append',
+                         help="Input bundle tags: '-it authoritative:True -it version:0.7.1'")
+    apply_p.add_argument('-ot', '--output-tag', nargs=1, type=str, action='append',
+                         help="Output bundle tags: '-ot authoritative:True -ot version:0.7.1'")
+    apply_p.add_argument('-o', '--output-bundle', type=str, default='-',
+                         help="Name output bundle: '-o my.output.bundle'.  Default name is '<TaskName>_<param_hash>'")
+    apply_p.add_argument('-f', '--force', action='store_true', help="Force re-computation of only this task.")
+    apply_p.add_argument('--force-all', action='store_true', help="Force re-computation of ALL upstream tasks.")
+    apply_p.add_argument('--incremental-push', action='store_true', help="Commit and push each task's bundle as it is produced to the remote.")
+    apply_p.add_argument('--incremental-pull', action='store_true', help="Localize bundles as they are needed by downstream tasks from the remote.")
+    apply_p.add_argument('pipe_cls', type=common.load_class, help="User-defined transform, e.g., 'module.PipeClass'")
+    apply_p.add_argument('params', type=str,  nargs=argparse.REMAINDER,
+                         help="Optional set of parameters for this pipe '--parameter value'")
+    apply_p.set_defaults(func=lambda args: cli_apply(args))
+
+
+
