@@ -1280,7 +1280,7 @@ class DisdatFS(object):
             local_hfr = self.get_hframe_by_uuid(s3_uuid, data_context=data_context)
             if local_hfr is not None:
                 if not localize:
-                    print("Found HyperFrame UUID {} present in local context, skipping . . .".format(s3_uuid))
+                    _logger.debug("Found HyperFrame UUID {} present in local context, skipping . . .".format(s3_uuid))
                 else:
                     if human_name is not None:
                         if human_name != local_hfr.pb.human_name:
@@ -1360,8 +1360,10 @@ def _commit(fs, args):
 
 
 def _remote(fs, args):
-    fs.remote_add(args.context, args.s3_url)
-
+    try:
+        fs.remote_add(args.context, args.s3_url)
+    except RuntimeError as rte:
+        pass
 
 def _push(fs, args):
     bundle = None
